@@ -11,29 +11,50 @@
 #'@param degrees Degrees of freedom
 #'@return The effect power for the parameters
 #'@keywords internal
-effectpower = function(RunMatrix, levelvector, anticoef, alpha, vinv = NULL, degrees=NULL) {
-
+effectpower = function(
+  RunMatrix,
+  levelvector,
+  anticoef,
+  alpha,
+  vinv = NULL,
+  degrees = NULL
+) {
   L = replicate(length(levelvector), matrix(NA, nrow = 0, ncol = 0))
 
   g = priorlevels(levelvector)
 
   for (i in 1:(length(g) - 1)) {
-    L[[i]] = genparammatrix(dim(attr(RunMatrix, "modelmatrix"))[2], levelvector[i], g[i])
+    L[[i]] = genparammatrix(
+      dim(attr(RunMatrix, "model.matrix"))[2],
+      levelvector[i],
+      g[i]
+    )
   }
   if (is.null(degrees)) {
-    degrees = rep(dim(attr(RunMatrix, "modelmatrix"))[1] -
-                    dim(attr(RunMatrix, "modelmatrix"))[2],length(L))
+    degrees = rep(
+      dim(attr(RunMatrix, "model.matrix"))[1] -
+        dim(attr(RunMatrix, "model.matrix"))[2],
+      length(L)
+    )
   } else {
-    degrees[is.na(degrees)] = dim(attr(RunMatrix, "modelmatrix"))[1] -
-      dim(attr(RunMatrix, "modelmatrix"))[2]
+    degrees[is.na(degrees)] = dim(attr(RunMatrix, "model.matrix"))[1] -
+      dim(attr(RunMatrix, "model.matrix"))[2]
   }
   power = c(length(L))
   for (j in 1:length(L)) {
-    if(degrees[j] != 0) {
-      power[j] = calculatepower(attr(RunMatrix, "modelmatrix"), L[[j]],
-                                calcnoncentralparam(attr(RunMatrix, "modelmatrix"),
-                                                    L[[j]], anticoef, vinv = vinv),
-                                alpha, degrees[j])
+    if (degrees[j] != 0) {
+      power[j] = calculatepower(
+        attr(RunMatrix, "model.matrix"),
+        L[[j]],
+        calcnoncentralparam(
+          attr(RunMatrix, "model.matrix"),
+          L[[j]],
+          anticoef,
+          vinv = vinv
+        ),
+        alpha,
+        degrees[j]
+      )
     } else {
       power[j] = NA
     }
